%global pypi_name cryptography

%bcond_without check

Name:           python-%{pypi_name}
Version:        44.0.1
Release:        %mkrel 2
Summary:        PyCA's cryptography library
Group:          Development/Python
License:        ASL 2.0 or BSD
URL:            https://cryptography.io/en/latest/
Source0:        https://github.com/pyca/cryptography/archive/%{version}/%{pypi_name}-%{version}.tar.gz
Patch1:         0001-build-remove-cargo.toml-files-from-wheels-12091.patch
BuildRequires:  openssl-devel
BuildRequires:  gcc
BuildRequires:  gnupg2
BuildRequires:  git-core
BuildRequires:  rust-packaging
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  %{name}-vectors >= %{version}

%description
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%package -n  python3-%{pypi_name}
Group:          Development/Python
Summary:        PyCA's cryptography library
%{?python_provide:%python_provide python3-%{pypi_name}}


%description -n python3-%{pypi_name}
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%prep
%autosetup -p1 -n %{pypi_name}-%{version} -Sgit_am
%cargo_prep

sed -i 's/locked = true//g' pyproject.toml

# Fix BRs
sed -i -e "s/\(['\"]\w\+\s*\)!=\([0-9]\+\(\.[0-9]\+\)\+\)\(,!=[0-9]\+\(\.[0-9]\)\+\)*/\1>\2/" pyproject.toml

%generate_buildrequires
%pyproject_buildrequires -x test
cd src/rust
%cargo_generate_buildrequires
cd ../..

%build
%pyproject_wheel

%install
# Actually other *.c and *.h are appropriate
# see https://github.com/pyca/cryptography/issues/1463
find . -name .keep -print -delete
%pyproject_install
%pyproject_save_files %{pypi_name}

%check
%if %{with check}
# see https://github.com/pyca/cryptography/issues/4885 and
# see https://bugzilla.redhat.com/show_bug.cgi?id=1761194 for deselected tests
# see rhbz#2042413 for memleak. It's unstable under Python 3.11 and makes
# not much sense for downstream testing.
# see rhbz#2171661 for test_load_invalid_ec_key_from_pem: error:030000CD:digital envelope routines::keymgmt export failure
PYTHONPATH=${PWD}/vectors:%{buildroot}%{python3_sitearch} \
    %{__python3} -m pytest \
    --ignore vendor \
    -k "not (test_buffer_protocol_alternate_modes or test_dh_parameters_supported or test_load_ecdsa_no_named_curve or test_decrypt_invalid_decrypt or test_openssl_memleak or test_load_invalid_ec_key_from_pem)"
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst docs
%license LICENSE*


%changelog
* Tue Feb 25 2025 wally <wally> 44.0.1-2.mga10
+ Revision: 2152537
- rebuild for python3.13

* Mon Feb 17 2025 wally <wally> 44.0.1-1.mga10
+ Revision: 2149263
- new version 44.0.1

* Wed Dec 18 2024 wally <wally> 44.0.0-1.mga10
+ Revision: 2126021
- new version 44.0.0

* Thu Mar 07 2024 wally <wally> 42.0.5-1.mga10
+ Revision: 2048429
- new version 42.0.5

* Sat Dec 30 2023 wally <wally> 41.0.7-1.mga10
+ Revision: 2024634
- new version 41.0.7
- add patches via upstream to port to pyo3 0.20

* Thu Dec 07 2023 wally <wally> 41.0.4-3.mga10
+ Revision: 2015195
- rebuild for py3.12

* Tue Nov 21 2023 wally <wally> 41.0.4-2.mga10
+ Revision: 2008875
- build using RUSTFLAGS
- add more strict BRs
+ papoteur <papoteur>
- new 41.0.4

* Thu Sep 07 2023 wally <wally> 41.0.3-1.mga10
+ Revision: 1985114
- new version 41.0.3

* Sat Feb 25 2023 wally <wally> 39.0.1-1.mga9
+ Revision: 1945366
- new version 39.0.1
- backport patches from upstream main branch and pyo3 0.18 update pull request

* Sun Jan 15 2023 wally <wally> 39.0.0-1.mga9
+ Revision: 1933467
- new version 39.0.0

* Thu Nov 24 2022 papoteur <papoteur> 38.0.3-1.mga9
+ Revision: 1910835
- new 38.0.3

* Mon Nov 14 2022 guillomovitch <guillomovitch> 37.0.4-1.mga9
+ Revision: 1907287
- new version 37.0.4
+ kekepower <kekepower>
- Update to version 38.0.3

* Tue Apr 12 2022 guillomovitch <guillomovitch> 36.0.1-3.mga9
+ Revision: 1849174
- use packaged rust build dependencies

* Wed Mar 30 2022 umeabot <umeabot> 36.0.1-2.mga9
+ Revision: 1834350
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 wally <wally> 36.0.1-1.mga9
+ Revision: 1773721
- build using vendored rust crates
- sync with Fedora where appropriate
- new version 36.0.1
- rebuild for python3.10
- rebuild for openssl 3.0.0

* Sat Aug 28 2021 wally <wally> 3.4.8-1.mga9
+ Revision: 1743125
- new version 3.4.8

* Sat Mar 20 2021 wally <wally> 3.4.6-1.mga9
+ Revision: 1705768
- skip rust build for now
+ tv <tv>
- rebuild for python-3.9.2
+ neoclust <neoclust>
- Rebuild against python 3.9
- New version 3.4.6
- New version 3.3.2: Fixes CVE-2020-36242 (mga#28384)

* Sun Dec 13 2020 guillomovitch <guillomovitch> 3.3.1-1.mga8
+ Revision: 1656427
- new version 3.3.1

* Sun Nov 01 2020 guillomovitch <guillomovitch> 3.2.1-1.mga8
+ Revision: 1641466
- new version 3.2.1

* Sat Sep 05 2020 guillomovitch <guillomovitch> 3.1-1.mga8
+ Revision: 1622539
- new version 3.1

* Thu Jul 16 2020 wally <wally> 2.9.2-2.mga8
+ Revision: 1606570
- add patch to drop boolean deps from generated requires

* Tue Jul 14 2020 guillomovitch <guillomovitch> 2.9.2-1.mga8
+ Revision: 1605987
- new version 2.9.2

* Thu Mar 05 2020 kekepower <kekepower> 2.8-1.mga8
+ Revision: 1554161
- Update to version 2.8

* Sun Feb 16 2020 umeabot <umeabot> 2.7-3.mga8
+ Revision: 1530733
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 2.7-2.mga8
+ Revision: 1437365
- rebuild for python3.8
- drop python2 support

* Sat Aug 10 2019 shlomif <shlomif> 2.7-1.mga8
+ Revision: 1428499
- New version 2.7

* Wed Apr 17 2019 wally <wally> 2.6.1-1.mga7
+ Revision: 1392288
- new version 2.6.1

* Mon Jan 14 2019 luigiwalser <luigiwalser> 2.4.2-1.mga7
+ Revision: 1356243
- 2.4.2

* Sat Jan 05 2019 wally <wally> 2.4.1-3.mga7
+ Revision: 1349622
- rebuild for python3.7 without tests

* Tue Jan 01 2019 wally <wally> 2.4.1-2.mga7
+ Revision: 1348079
- build with tests

* Mon Dec 31 2018 luigiwalser <luigiwalser> 2.4.1-1.mga7
+ Revision: 1347714
- disable check for now as newer pytest is required
- 2.4.1

* Wed Oct 24 2018 bcornec <bcornec> 2.3.1-1.mga7
+ Revision: 1325064
- update to upstream python-cryptography 2.3.1

* Sun Sep 23 2018 umeabot <umeabot> 2.2.2-3.mga7
+ Revision: 1300463
- Mageia 7 Mass Rebuild

* Wed Jul 25 2018 daviddavid <daviddavid> 2.2.2-2.mga7
+ Revision: 1245162
- remove some hard requires that are already auto-required

* Fri Apr 20 2018 kekepower <kekepower> 2.2.2-1.mga7
+ Revision: 1220456
- Update to version 2.2.2
- Use python_provide

* Thu Jan 04 2018 guillomovitch <guillomovitch> 2.1.4-1.mga7
+ Revision: 1190122
- new version 2.1.4
- new version 2.1.4

* Thu Oct 05 2017 tv <tv> 2.0.3-4.mga7
+ Revision: 1169083
- add BR on python2dist(asn1crypto) thus fixing build

* Sun Aug 06 2017 neoclust <neoclust> 2.0.3-3.mga7
+ Revision: 1137753
- Add missing provide

* Sun Aug 06 2017 joequant <joequant> 2.0.3-2.mga7
+ Revision: 1137541
- convert to new conventions python

* Sat Aug 05 2017 philippem <philippem> 2.0.3-1.mga7
+ Revision: 1135143
- update to 2.0.3, rebuild for Python 3.6

* Fri Nov 11 2016 philippem <philippem> 1.5.3-1.mga6
+ Revision: 1066348
- update to 1.5.3, fix CVE-2016-9243 mga#19736

* Fri Oct 28 2016 philippem <philippem> 1.5.2-1.mga6
+ Revision: 1063822
- add BR on pytz
- update to 1.5.2

* Tue May 17 2016 philippem <philippem> 1.3.2-1.mga6
+ Revision: 1016543
- update to 1.3.2

* Sun Apr 10 2016 philippem <philippem> 1.3.1-1.mga6
+ Revision: 1000033
- update to 1.3.1

* Sat Mar 05 2016 philippem <philippem> 1.2.3-1.mga6
+ Revision: 986120
- update to 1.2.3
- update to 1.2.3
+ umeabot <umeabot>
- Rebuild for openssl

* Sat Feb 13 2016 philippem <philippem> 1.2.2-1.mga6
+ Revision: 959785
- update to 1.2.2

* Fri Dec 04 2015 philippem <philippem> 1.1.1-1.mga6
+ Revision: 908237
- add BR for tests, disable python3 tests
- update to 1.1.1

* Thu Oct 29 2015 philippem <philippem> 1.1-1.mga6
+ Revision: 896476
- update to 1.1

* Sun Oct 11 2015 philippem <philippem> 1.0.2-1.mga6
+ Revision: 889682
- update to 1.0.2

* Thu Oct 08 2015 tv <tv> 1.0.1-2.mga6
+ Revision: 887747
- rebuild for python 3.5

* Thu Sep 24 2015 philippem <philippem> 1.0.1-1.mga6
+ Revision: 883390
- update to 1.0.1

* Sun Mar 08 2015 philippem <philippem> 0.7.2-1.mga5
+ Revision: 818107
- imported package python-cryptography

